@@ -15,6 +15,10 @@ package Params::Callbacks;
 
 Params::Callbacks - Make your subroutines accept blocking callbacks
 
+=head1 VERSION
+
+version 2.002004
+
 =head1 SYNOPSIS
 
     use Params::Callbacks 'callbacks', 'callback';  # Or use ':all' tag
@@ -25,12 +29,14 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
 
     sub foo
     {
-        my ( $callbacks, @params ) = &callbacks;    # If &callbacks makes the hairs
-                                                    # on your neck standp, then use
-                                                    # a cleaner alternative:
-                                                    #
-                                                    # - callbacks(@_), or ...
-                                                    # - Params::Callbacks->new(@_)
+        my ( $callbacks, @params ) = &callbacks;
+        # If &callbacks makes the hairs
+        # on your neck standp, then use
+        # a cleaner alternative:
+        #
+        # - callbacks(@_), or ...
+        # - Params::Callbacks->new(@_)
+
         return $callbacks->transform(@params);
     }
 
@@ -84,9 +90,9 @@ chain is terminated for that value.
     package MyModule;
     use Exporter;
     use Params::Callbacks 'callbacks';
-    use namespace::clean;               # Because you might do this ...
-    use Params::Callbacks 'callback';   # We do this to make "callback" available
-    our @EXPORT = 'callback';           # Maybe, maybe not. Up to you.
+    use namespace::clean;
+    use Params::Callbacks 'callback';
+    our @EXPORT = 'callback';
     our @EXPORT_OK = 'awesome';
     our @ISA = 'Exporter';
 
@@ -134,11 +140,10 @@ chain is terminated for that value.
     use MyModule 'awesome';
     my @team = awesome('Imran', 'Merlyn', 'Iain', callback {
         "$_, you're awesome!"
-    }                                   # Comma is optional here.
+    } # Comma is optional here.
     callback {
-        my ($name) = @_;
-        print "$name\n";
-        return $name;
+        print "$_[0]\n";
+        return $_[0];
     });
     #
     # Imran, you're awesome!
@@ -350,7 +355,13 @@ sub callback (&;@)
 
 =head1 REPOSITORY
 
-L<Params-Callbacks at GitHub|https://github.com/cpanic/Params-Callbacks>
+=over 2
+
+=item * L<http://search.cpan.org/dist/Params-Callbacks/lib/Params/Callbacks.pm>
+
+=item * L<https://github.com/cpanic/Params-Callbacks>
+
+=back
 
 =head1 BUG REPORTS
 
